"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var app = require("tns-core-modules/application");
var permissions = require("nativescript-perms");
function callIntent(context, intent, pickerType) {
    return permissions.request('storage').then(function () {
        return new Promise(function (resolve, reject) {
            var onEvent = function (e) {
                console.log('startActivityForResult ', e.requestCode);
                if (e.requestCode === pickerType) {
                    resolve(e);
                    app.android.off(app.AndroidApplication.activityResultEvent, onEvent);
                }
            };
            app.android.once(app.AndroidApplication.activityResultEvent, onEvent);
            context.startActivityForResult(intent, pickerType);
        });
    });
}
function setMimeTypeOnIntent(intent, allowedTypes) {
    if (allowedTypes.length === 0) {
        return;
    }
    var extensions = Array.create(java.lang.String, allowedTypes.length);
    for (var i = 0; i < allowedTypes.length; i++) {
        extensions[i] = allowedTypes[i];
    }
    if (extensions.length > 1) {
        intent.setType("*/*");
        intent.putExtra(android.content.Intent.EXTRA_MIME_TYPES, extensions);
    }
    else {
        intent.setType(extensions[0]);
    }
}
var UriHelper = (function () {
    function UriHelper() {
    }
    UriHelper._calculateFileUri = function (uri) {
        var DocumentsContract = android.provider.DocumentsContract;
        var isKitKat = android.os.Build.VERSION.SDK_INT >= 19;
        if (isKitKat && DocumentsContract.isDocumentUri(app.android.context, uri)) {
            var docId = void 0, id = void 0, type = void 0;
            var contentUri = null;
            if (UriHelper.isExternalStorageDocument(uri)) {
                docId = DocumentsContract.getDocumentId(uri);
                id = docId.split(":")[1];
                type = docId.split(":")[0];
                if ("primary" === type.toLowerCase()) {
                    return android.os.Environment.getExternalStorageDirectory() + "/" + id;
                }
                else {
                    if (android.os.Build.VERSION.SDK_INT > 23) {
                        this.getContentResolver().takePersistableUriPermission(uri, android.content.Intent.FLAG_GRANT_READ_URI_PERMISSION | android.content.Intent.FLAG_GRANT_WRITE_URI_PERMISSION);
                        var externalMediaDirs = app.android.context.getExternalMediaDirs();
                        if (externalMediaDirs.length > 1) {
                            var filePath = externalMediaDirs[1].getAbsolutePath();
                            filePath = filePath.substring(0, filePath.indexOf("Android")) + id;
                            return filePath;
                        }
                    }
                }
            }
            else if (UriHelper.isDownloadsDocument(uri)) {
                return UriHelper.getDataColumn(uri, null, null, true, false);
            }
            else if (UriHelper.isMediaDocument(uri)) {
                docId = DocumentsContract.getDocumentId(uri);
                var split = docId.split(":");
                type = split[0];
                id = split[1];
                if ("image" === type) {
                    contentUri = android.provider.MediaStore.Images.Media.EXTERNAL_CONTENT_URI;
                }
                else if ("video" === type) {
                    contentUri = android.provider.MediaStore.Video.Media.EXTERNAL_CONTENT_URI;
                }
                else if ("audio" === type) {
                    contentUri = android.provider.MediaStore.Audio.Media.EXTERNAL_CONTENT_URI;
                }
                else if ("document" === type) {
                    contentUri = android.provider.MediaStore.Files.getContentUri('external');
                }
                var selection = "_id=?";
                var selectionArgs = [id];
                return UriHelper.getDataColumn(contentUri, selection, selectionArgs, false, type === "document");
            }
        }
        else {
            if ("content" === uri.getScheme()) {
                return UriHelper.getDataColumn(uri, null, null, false, false);
            }
            else if ("file" === uri.getScheme()) {
                return uri.getPath();
            }
        }
        return undefined;
    };
    UriHelper.getDataColumn = function (uri, selection, selectionArgs, isDownload, isFile) {
        var cursor = null;
        var filePath;
        if (isDownload) {
            var columns = ["_display_name"];
            try {
                cursor = this.getContentResolver().query(uri, columns, selection, selectionArgs, null);
                if (cursor != null && cursor.moveToFirst()) {
                    var column_index = cursor.getColumnIndexOrThrow(columns[0]);
                    filePath = cursor.getString(column_index);
                    if (filePath) {
                        var dl = android.os.Environment.getExternalStoragePublicDirectory(android.os.Environment.DIRECTORY_DOWNLOADS);
                        filePath = dl + "/" + filePath;
                        return filePath;
                    }
                }
            }
            catch (e) {
                console.log(e);
            }
            finally {
                if (cursor) {
                    cursor.close();
                }
            }
        }
        else if (isFile) {
            var columns = [android.provider.MediaStore.Files.FileColumns.DATA];
            var filePath_1;
            try {
                cursor = this.getContentResolver().query(uri, columns, selection, selectionArgs, null);
                if (cursor != null && cursor.moveToFirst()) {
                    var column_index = cursor.getColumnIndexOrThrow(columns[0]);
                    filePath_1 = cursor.getString(column_index);
                    if (filePath_1) {
                        return filePath_1;
                    }
                }
            }
            catch (e) {
                console.log(e);
            }
            finally {
                if (cursor) {
                    cursor.close();
                }
            }
        }
        else {
            var columns = [android.provider.MediaStore.MediaColumns.DATA];
            var filePath_2;
            try {
                cursor = this.getContentResolver().query(uri, columns, selection, selectionArgs, null);
                if (cursor != null && cursor.moveToFirst()) {
                    var column_index = cursor.getColumnIndexOrThrow(columns[0]);
                    filePath_2 = cursor.getString(column_index);
                    if (filePath_2) {
                        return filePath_2;
                    }
                }
            }
            catch (e) {
                console.log(e);
            }
            finally {
                if (cursor) {
                    cursor.close();
                }
            }
        }
        return undefined;
    };
    UriHelper.isExternalStorageDocument = function (uri) {
        return "com.android.externalstorage.documents" === uri.getAuthority();
    };
    UriHelper.isDownloadsDocument = function (uri) {
        return "com.android.providers.downloads.documents" === uri.getAuthority();
    };
    UriHelper.isMediaDocument = function (uri) {
        return "com.android.providers.media.documents" === uri.getAuthority();
    };
    UriHelper.getContentResolver = function () {
        return app.android.nativeApp.getContentResolver();
    };
    return UriHelper;
}());
var FilePicker = (function () {
    function FilePicker() {
        this.openFilePicker = function (params) {
            var context = app.android.foregroundActivity || app.android.startActivity;
            var FILE_CODE = 1231;
            var intent = new android.content.Intent(android.content.Intent.ACTION_GET_CONTENT);
            intent.addCategory(android.content.Intent.CATEGORY_OPENABLE);
            intent.setAction(android.content.Intent.ACTION_OPEN_DOCUMENT);
            intent.putExtra(android.content.Intent.EXTRA_ALLOW_MULTIPLE, params && !!params.multipleSelection || false);
            var allowedTypes = params ? params.extensions : [];
            setMimeTypeOnIntent(intent, allowedTypes);
            return callIntent(context, intent, FILE_CODE).then(function (result) {
                if (result.resultCode === android.app.Activity.RESULT_OK) {
                    if (result.intent != null) {
                        var uri = result.intent.getData();
                        var uris = [uri];
                        if (!uri) {
                            uris = [];
                            var clipData = result.intent.getClipData();
                            if (clipData) {
                                for (var i = 0; i < clipData.getItemCount(); i++) {
                                    var clipDataItem = clipData.getItemAt(i);
                                    var fileUri = clipDataItem.getUri();
                                    uris.push(fileUri);
                                }
                            }
                        }
                        var paths = uris.map(function (uri) {
                            var customUri = UriHelper._calculateFileUri(uri);
                            if (customUri && customUri !== '') {
                                return customUri;
                            }
                            else {
                                return com.nativescript.simple.FilePicker.getPath(context, uri);
                            }
                        });
                        return {
                            files: paths
                        };
                    }
                    return {
                        files: []
                    };
                }
                else {
                    throw new Error('no_file');
                }
            });
        };
    }
    return FilePicker;
}());
exports.FilePicker = FilePicker;
//# sourceMappingURL=simple-filepicker.android.js.map